==> igniteui-react-charts-16.16.1.tgz: package/esm2015/lib/StepAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { typeCast, Array_$type, runOn, markType } from "igniteui-react-core";
import { ISortingAxis_$type } from "./ISortingAxis";
import { List$1 } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { intDivide, isNaN_ } from "igniteui-react-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
export let StepAreaSeries = /*@__PURE__*/ (() => {
    class StepAreaSeries extends HorizontalAnchoredCategorySeries {
        constructor() {
            super();
            this.u7 = null;
            this.u7 = new CategoryLineRasterizer();
            this.ab = StepAreaSeries.$;
        }
        bx() {
            return new StepAreaSeriesView(this);
        }
        lz(a) {
            super.lz(a);
            this.u8 = a;
        }
        get_de() {
            return true;
        }
        get_dd() {
            return true;
        }
        get_eh() {
            return true;
        }
        get_d2() {
            return true;
        }
        b3() {
            if (this.b4 == 0) {
                return 2;
            }
            return super.b3();
        }
        preferredCategoryMode(a) {
            return typeCast(ISortingAxis_$type, a) !== null ? 0 : 1;
        }
        kx(a, b) {
            super.kx(a, b);
            let c = b;
            c.db();
        }
        u9(a, b, c, d, e) {
            if (b) {
                if (e) {
                    if ((a & 1) == 0 || ((intDivide(a, 2)) + 1) >= c.f.count) {
                        return c.f._inner[(intDivide(a, 2))][0];
                    }
                    return c.f._inner[(intDivide(a, 2)) + 1][0];
                }
                return c.f._inner[(intDivide(a, 2))][0] + ((a & 1) == 1 ? -d : d);
            }
            if (e) {
                if ((a & 1) == 0 || ((intDivide(a, 2)) + 1) >= c.f.count) {
                    return c.f._inner[(intDivide(a, 2))][0];
                }
                return c.f._inner[(intDivide(a, 2)) + 1][0];
            }
            return c.f._inner[(intDivide(a, 2))][0] + ((a & 1) == 0 ? -d : d);
        }
        rz() {
            return 1;
        }
        f9(a, b, c, d, e, f, g, h) {
            let i = NaN;
            if (c >= 0 && c < b.count) {
                i = b.item(c);
            }
            let j = NaN;
            if (d >= 0 && d < b.count) {
                j = b.item(d);
            }
            if (f == 0) {
                return j;
            }
            if (e == b.count - 1) {
                return i;
            }
            if (isNaN_(j) && g != 0 && a <= 0.5 && !h) {
                return i;
            }
            if (isNaN_(i) && g != 0 && a >= 0.5 && !h) {
                return j;
            }
            if (a > 0.5) {
                return j;
            }
            return i;
        }
        bp() {
            if (this.bq == 0) {
                return 2;
            }
            else {
                return super.bp();
            }
        }
        s7(a, b) {
            super.s7(a, b);
            let c = b.bv;
            let d = b.bu;
            let e = this.getEffectiveViewport1(b);
            let f = typeCast(ISortingAxis_$type, this.uo) != null;
            let g = this.uo != null ? 0.5 * this.uo.getCategorySize(c, d, e) : 0;
            if (this.uo != null && this.uo.cg) {
                g = -g;
            }
            let h = a.f.count * 2;
            let i = new List$1(Array_$type, 2, h);
            this.rx.a0(this, this.sh(), runOn(this, this.ri), this.sp(b), this.sq(b));
            let j = false;
            let k = this.rx.b;
            if (k != null) {
                j = true;
            }
            for (let l = 0; l < h; l++) {
                let m = new Array(4);
                m[0] = this.u9(l, false, a, g, f);
                m[1] = a.f._inner[(intDivide(l, 2))][1];
                m[2] = this.u9(l, true, a, g, f);
                m[3] = a.f._inner[(intDivide(l, 2))][2];
                i.add(m);
            }
            let n = this.ry.cr.d;
            if (j) {
                let o = new ScalerParams(0, b.bv, b.bu, this.uo.cg, e);
                this.s3(i, -1, this.valueColumn.count, this.uo, o, b.q);
            }
            let p = typeCast(StepAreaSeriesView.$, b);
            let q = p.dp;
            let r = p.dq;
            let s = p.dm;
            let t = p.dn;
            this.rx.ad(q, true, false, true, true);
            this.rx.ad(r, true, false, true, true);
            this.rx.ad(s, false, true, false, false);
            this.rx.ad(t, false, true, false, false);
            if (b.cv(a)) {
                p.dd(h, i, false, n, this.ft, (u, v, w, x, y) => this.t6(u, 2 * a.f.count, b), 1, this.tg(i, i.count - 1, b.bu, b.bv, true));
                b.cy(a);
            }
            let u = this.fetchYAxis();
            p.dm._opacity = this.rx.j * this.fq;
            p.dn._opacity = 0.5 * this.rx.j * this.fq;
        }
        get useHighMarkerFidelity() {
            return this.sk;
        }
    }
    StepAreaSeries.$t = /*@__PURE__*/ markType(StepAreaSeries, 'StepAreaSeries', HorizontalAnchoredCategorySeries.$);
    return StepAreaSeries;
})();
/**
 * @hidden
 */
export let StepAreaSeriesView = /*@__PURE__*/ (() => {
    class StepAreaSeriesView extends AnchoredCategorySeriesView {
        constructor(a) {
            super(a);
            this.da = null;
            this.di = new Path();
            this.dk = new Path();
            this.dj = new Path();
            this.dl = new Path();
            this.de = new Path();
            this.dg = new Path();
            this.df = new Path();
            this.dh = new Path();
            this.da = a;
        }
        as() {
            super.as();
            if (!this.q) {
                this.da.qd = Defaults.c;
            }
        }
        get dm() {
            return this.di;
        }
        get dp() {
            return this.dk;
        }
        get dn() {
            return this.dj;
        }
        get dq() {
            return this.dl;
        }
        db() {
            this.di.ak = null;
            this.dj.ak = null;
            this.dk.ak = null;
            this.dl.ak = null;
            this.aq();
        }
        dc(a, b, c, d, e, f, g) {
            this.dc(a, b, c, d, e, f, g);
        }
        dd(a, b, c, d, e, f, g, h) {
            this.da.u7.a = typeCast(ISortingAxis_$type, this.ct.fetchXAxis()) !== null ? true : false;
            this.da.u7.j(this.di, this.dk, this.dj, this.dl, a, b, c, d, e, f, g, h);
            this.aq();
        }
        bc() {
            super.bc();
            this.de.ak = this.di.ak;
            this.dg.ak = this.dk.ak;
            this.df.ak = this.dj.ak;
            this.dh.ak = this.dl.ak;
            let a = this.bo();
            this.de._fill = a;
            this.de._opacity = 1;
            this.df._fill = a;
            this.df._opacity = 1;
            this.dg._stroke = a;
            this.dg.ac = this.e.fu + 3;
            this.dh._stroke = a;
            this.dh.ac = this.e.fu + 3;
        }
        a6(a, b) {
            super.a6(a, b);
            if (b) {
                a.s(this.de);
                a.s(this.df);
                a.s(this.dg);
                a.s(this.dh);
            }
            else {
                a.s(this.di);
                a.s(this.dj);
                a.s(this.dk);
                a.s(this.dl);
            }
        }
        al(a) {
            super.al(a);
            this.e.a8.exportPathData(a, this.dk, "lowerShape", ["Lower"]);
            this.e.a8.exportPathData(a, this.dl, "upperShape", ["Upper", "Main"]);
            this.e.a8.exportPathData(a, this.dj, "translucentShape", ["Translucent"]);
            this.e.a8.exportPathData(a, this.di, "fillShape", ["Fill"]);
        }
    }
    StepAreaSeriesView.$t = /*@__PURE__*/ markType(StepAreaSeriesView, 'StepAreaSeriesView', AnchoredCategorySeriesView.$);
    return StepAreaSeriesView;
})();

==> igniteui-react-charts-18.1.0.tgz: package/esm2015/lib/StepAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { typeCast, Array_$type, runOn, markType } from "igniteui-react-core";
import { ISortingAxis_$type } from "./ISortingAxis";
import { List$1 } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { intDivide, isNaN_ } from "igniteui-react-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
export let StepAreaSeries = /*@__PURE__*/ (() => {
    class StepAreaSeries extends HorizontalAnchoredCategorySeries {
        constructor() {
            super();
            this.vb = null;
            this.vb = new CategoryLineRasterizer();
            this.ab = StepAreaSeries.$;
        }
        bx() {
            return new StepAreaSeriesView(this);
        }
        l2(a) {
            super.l2(a);
            this.vc = a;
        }
        get_de() {
            return true;
        }
        get_dd() {
            return true;
        }
        get_ei() {
            return true;
        }
        get_d3() {
            return true;
        }
        b3() {
            if (this.b4 == 0) {
                return 2;
            }
            return super.b3();
        }
        preferredCategoryMode(a) {
            return typeCast(ISortingAxis_$type, a) !== null ? 0 : 1;
        }
        k0(a, b) {
            super.k0(a, b);
            let c = b;
            c.db();
        }
        vd(a, b, c, d, e) {
            if (b) {
                if (e) {
                    if ((a & 1) == 0 || ((intDivide(a, 2)) + 1) >= c.f.count) {
                        return c.f._inner[(intDivide(a, 2))][0];
                    }
                    return c.f._inner[(intDivide(a, 2)) + 1][0];
                }
                return c.f._inner[(intDivide(a, 2))][0] + ((a & 1) == 1 ? -d : d);
            }
            if (e) {
                if ((a & 1) == 0 || ((intDivide(a, 2)) + 1) >= c.f.count) {
                    return c.f._inner[(intDivide(a, 2))][0];
                }
                return c.f._inner[(intDivide(a, 2)) + 1][0];
            }
            return c.f._inner[(intDivide(a, 2))][0] + ((a & 1) == 0 ? -d : d);
        }
        r3() {
            return 1;
        }
        gb(a, b, c, d, e, f, g, h) {
            let i = NaN;
            if (c >= 0 && c < b.count) {
                i = b.item(c);
            }
            let j = NaN;
            if (d >= 0 && d < b.count) {
                j = b.item(d);
            }
            if (f == 0) {
                return j;
            }
            if (e == b.count - 1) {
                return i;
            }
            if (isNaN_(j) && g != 0 && a <= 0.5 && !h) {
                return i;
            }
            if (isNaN_(i) && g != 0 && a >= 0.5 && !h) {
                return j;
            }
            if (a > 0.5) {
                return j;
            }
            return i;
        }
        bp() {
            if (this.bq == 0) {
                return 2;
            }
            else {
                return super.bp();
            }
        }
        tb(a, b) {
            super.tb(a, b);
            let c = b.bv;
            let d = b.bu;
            let e = this.getEffectiveViewport1(b);
            let f = typeCast(ISortingAxis_$type, this.us) != null;
            let g = this.us != null ? 0.5 * this.us.getCategorySize(c, d, e) : 0;
            if (this.us != null && this.us.cg) {
                g = -g;
            }
            let h = a.f.count * 2;
            let i = new List$1(Array_$type, 2, h);
            this.r1.a0(this, this.sl(), runOn(this, this.rm), this.st(b), this.su(b));
            let j = false;
            let k = this.r1.b;
            if (k != null) {
                j = true;
            }
            for (let l = 0; l < h; l++) {
                let m = new Array(4);
                m[0] = this.vd(l, false, a, g, f);
                m[1] = a.f._inner[(intDivide(l, 2))][1];
                m[2] = this.vd(l, true, a, g, f);
                m[3] = a.f._inner[(intDivide(l, 2))][2];
                i.add(m);
            }
            let n = this.r2.cr.d;
            if (j) {
                let o = new ScalerParams(0, b.bv, b.bu, this.us.cg, e);
                this.s7(i, -1, this.valueColumn.count, this.us, o, b.q);
            }
            let p = typeCast(StepAreaSeriesView.$, b);
            let q = p.dp;
            let r = p.dq;
            let s = p.dm;
            let t = p.dn;
            this.r1.ad(q, true, false, true, true);
            this.r1.ad(r, true, false, true, true);
            this.r1.ad(s, false, true, false, false);
            this.r1.ad(t, false, true, false, false);
            if (b.cv(a)) {
                p.dd(h, i, false, n, this.fv, (u, v, w, x, y) => this.ua(u, 2 * a.f.count, b), 1, this.tk(i, i.count - 1, b.bu, b.bv, true));
                b.cy(a);
            }
            let u = this.fetchYAxis();
            p.dm._opacity = this.r1.j * this.fs;
            p.dn._opacity = 0.5 * this.r1.j * this.fs;
        }
        get useHighMarkerFidelity() {
            return this.so;
        }
    }
    StepAreaSeries.$t = /*@__PURE__*/ markType(StepAreaSeries, 'StepAreaSeries', HorizontalAnchoredCategorySeries.$);
    return StepAreaSeries;
})();
/**
 * @hidden
 */
export let StepAreaSeriesView = /*@__PURE__*/ (() => {
    class StepAreaSeriesView extends AnchoredCategorySeriesView {
        constructor(a) {
            super(a);
            this.da = null;
            this.di = new Path();
            this.dk = new Path();
            this.dj = new Path();
            this.dl = new Path();
            this.de = new Path();
            this.dg = new Path();
            this.df = new Path();
            this.dh = new Path();
            this.da = a;
        }
        as() {
            super.as();
            if (!this.q) {
                this.da.qh = Defaults.c;
            }
        }
        get dm() {
            return this.di;
        }
        get dp() {
            return this.dk;
        }
        get dn() {
            return this.dj;
        }
        get dq() {
            return this.dl;
        }
        db() {
            this.di.ak = null;
            this.dj.ak = null;
            this.dk.ak = null;
            this.dl.ak = null;
            this.aq();
        }
        dc(a, b, c, d, e, f, g) {
            this.dc(a, b, c, d, e, f, g);
        }
        dd(a, b, c, d, e, f, g, h) {
            this.da.vb.a = typeCast(ISortingAxis_$type, this.ct.fetchXAxis()) !== null ? true : false;
            this.da.vb.j(this.di, this.dk, this.dj, this.dl, a, b, c, d, e, f, g, h);
            this.aq();
        }
        bc() {
            super.bc();
            this.de.ak = this.di.ak;
            this.dg.ak = this.dk.ak;
            this.df.ak = this.dj.ak;
            this.dh.ak = this.dl.ak;
            let a = this.bo();
            this.de._fill = a;
            this.de._opacity = 1;
            this.df._fill = a;
            this.df._opacity = 1;
            this.dg._stroke = a;
            this.dg.ac = this.e.fw + 3;
            this.dh._stroke = a;
            this.dh.ac = this.e.fw + 3;
        }
        a6(a, b) {
            super.a6(a, b);
            if (b) {
                a.s(this.de);
                a.s(this.df);
                a.s(this.dg);
                a.s(this.dh);
            }
            else {
                a.s(this.di);
                a.s(this.dj);
                a.s(this.dk);
                a.s(this.dl);
            }
        }
        al(a) {
            super.al(a);
            this.e.a8.exportPathData(a, this.dk, "lowerShape", ["Lower"]);
            this.e.a8.exportPathData(a, this.dl, "upperShape", ["Upper", "Main"]);
            this.e.a8.exportPathData(a, this.dj, "translucentShape", ["Translucent"]);
            this.e.a8.exportPathData(a, this.di, "fillShape", ["Fill"]);
        }
    }
    StepAreaSeriesView.$t = /*@__PURE__*/ markType(StepAreaSeriesView, 'StepAreaSeriesView', AnchoredCategorySeriesView.$);
    return StepAreaSeriesView;
})();
